EXPORTS
	??1CSdpAgent@@UAE@XZ @ 1 NONAME ; public: virtual __thiscall CSdpAgent::~CSdpAgent(void)
	?AttributeRequestL@CSdpAgent@@QAEXKABVCSdpAttrIdMatchList@@@Z @ 2 NONAME ; public: void __thiscall CSdpAgent::AttributeRequestL(unsigned long,class CSdpAttrIdMatchList const &)
	?AttributeRequestL@CSdpAgent@@QAEXKG@Z @ 3 NONAME ; public: void __thiscall CSdpAgent::AttributeRequestL(unsigned long,unsigned short)
	?AttributeRequestL@CSdpAgent@@QAEXPAVMSdpElementBuilder@@KABVCSdpAttrIdMatchList@@@Z @ 4 NONAME ; public: void __thiscall CSdpAgent::AttributeRequestL(class MSdpElementBuilder *,unsigned long,class CSdpAttrIdMatchList const &)
	?AttributeRequestL@CSdpAgent@@QAEXPAVMSdpElementBuilder@@KG@Z @ 5 NONAME ; public: void __thiscall CSdpAgent::AttributeRequestL(class MSdpElementBuilder *,unsigned long,unsigned short)
	?NewL@CSdpAgent@@SAPAV1@AAVMSdpAgentNotifier@@ABVTBTDevAddr@@@Z @ 6 NONAME ; public: static class CSdpAgent * __cdecl CSdpAgent::NewL(class MSdpAgentNotifier &,class TBTDevAddr const &)
	?NewLC@CSdpAgent@@SAPAV1@AAVMSdpAgentNotifier@@ABVTBTDevAddr@@@Z @ 7 NONAME ; public: static class CSdpAgent * __cdecl CSdpAgent::NewLC(class MSdpAgentNotifier &,class TBTDevAddr const &)
	?NextRecordRequestL@CSdpAgent@@QAEXXZ @ 8 NONAME ; public: void __thiscall CSdpAgent::NextRecordRequestL(void)
	?SetAttributePredictorListL@CSdpAgent@@QAEXABVCSdpAttrIdMatchList@@@Z @ 9 NONAME ; public: void __thiscall CSdpAgent::SetAttributePredictorListL(class CSdpAttrIdMatchList const &)
	?SetRecordFilterL@CSdpAgent@@QAEXABVCSdpSearchPattern@@@Z @ 10 NONAME ; public: void __thiscall CSdpAgent::SetRecordFilterL(class CSdpSearchPattern const &)
	?Cancel@CSdpAgent@@QAEXXZ @ 11 NONAME ; public: void __thiscall CSdpAgent::Cancel(void)

